v6.x.y - Jumeaux
Author: tadashi-aikawa
Description: Check difference between two responses of API.

コンテンツにスキップ

# Version 6.0～7.0

Version6.0～7.0までのリリースノートです。

## 6.1.0

`2026-03-11`

miroir addon で DynamoDB と S3 の endpoint を個別指定できるようになりました

- Moto などを使って DynamoDB / S3 の接続先を個別に切り替えられます
- 詳細は miroir > Endpoints をご覧ください

Python3.9のサポートを終了しました

セキュリティアップデート

## 6.0.1

`2025-09-27`

セキュリティアップデート

## 6.0.0

`2025-01-04`

Python3.13をサポートするようになりました

Python3.8のサポートを終了しました

セキュリティアップデート

Poetryの代わりにuvを使用するようにしました